<?php
/**
 * $Id: dates.php 52 2014-07-07 12:17:31Z Szablac $
 * @Project		Saxum Astro Extension/Component
 * @author 		Laszlo Szabo
 * @package		Saxum Astro
 * @copyright	Copyright (C) 2010 Saxum 2003 Bt. All rights reserved.
 * @license 	http://www.gnu.org/licenses/old-licenses/gpl-3.0.html GNU/GPL version 3
*/
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport( 'joomla.application.component.modellist' );

class SaxumastroModelDates extends JModelList
{	
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'a.id',
				'signid', 'a.signid' ,
				'signname', 's.name' ,
				'number', 'a.number' ,
				'typeid', 's.typeid',
				'typename', 't.name',			
				'date_from', 'a.date_from' 
			);
		}

		parent::__construct($config);
	}
	
	protected function getListQuery()
	{
		// Create a new query object.		
		$db = $this->getDBO();
		$query = $db->getQuery(true);
		// Select some fields
		$query->select(
			$this->getState(
				'list.select',
				'a.*'
				)
			);
		$query->from('#__saxumastro_dates a');
		
		$query->select('s.name AS signname');
		$query->join('INNER', '#__saxumastro_sign AS s ON a.signid=s.id');
			
		$query->select('t.name AS typename, t.signtype');
		$query->join('INNER', '#__saxumastro_type AS t ON s.typeid=t.id');
		
		// Filter by search in title.
		$search = $this->getState('filter.search');
		if (!empty($search))
		{
			if (stripos($search, 'id:') === 0)
			{
				$query->where('a.id = ' . (int) substr($search, 3));
			}
			elseif (stripos($search, 'type:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 5), true) . '%');
				$query->where('(t.name LIKE ' . $search . ')');
			}
			elseif (stripos($search, 'sign:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 5), true) . '%');
				$query->where('(s.name LIKE ' . $search . ')');
			}
			elseif (stripos($search, 'number:') === 0)
			{
				$search = $db->quote('%' . $db->escape(substr($search, 7), true) . '%');
				$query->where('(a.number LIKE ' . $search . ')');
			}
			else
			{
				$search = $db->quote('%' . $db->escape($search, true) . '%');
				$query->where('(s.name LIKE ' . $search . ')');
			}
		}

		// Filter by sign
		$signId = $this->getState('filter.signid');
		if (is_numeric($signId)) {
			$query->where('a.signid = '.(int) $signId);
		}				
		// Filter by type
		$typeId = $this->getState('filter.typeid');
		if (is_numeric($typeId)) {
			$query->where('s.typeid = '.(int) $typeId);
		}
		
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
		$query->order($db->escape($orderCol.' '.$orderDirn));
		
		return $query;
	}
		
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		$search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		// Load the filter state.
		$signId = $this->getUserStateFromRequest($this->context.'.filter.signid', 'filter_signid', '');
		$this->setState('filter.signid', $signId);
		
		$typeId = $this->getUserStateFromRequest($this->context.'.filter.typeid', 'filter_typeid', '');
		$this->setState('filter.typeid', $typeId);

		// List state information.
		parent::populateState('signname', 'asc');
	}

	public function getSigns()
	{
		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);

		$query->select('s.id, s.name AS signname');
		$query->from('#__saxumastro_sign AS s');
		$query->order('s.name ASC');

		$db->setQuery($query);
		$result = $db->loadObjectList();

		return $result;
	}

	public function getTypes()
	{
		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);

		$query->select('t.id, t.name AS typename');
		$query->from('#__saxumastro_type AS t');
		$query->order('t.name ASC');

		$db->setQuery($query);
		$result = $db->loadObjectList();

		return $result;
	}
	
}
  	
